@@ -74,19 +74,14 @@ public abstract class AbstractCompiler
     //
     // ----------------------------------------------------------------------
 
+    public abstract String getCompilerId();
+
     public CompilerResult performCompile(CompilerConfiguration configuration)
             throws CompilerException 
     {
         throw new CompilerNotImplementedException("The performCompile method has not been implemented.");
     }
 
-    @Deprecated
-    public List<CompilerError> compile(CompilerConfiguration configuration)
-            throws CompilerException
-    {
-        throw new CompilerNotImplementedException("The compile method has not been implemented.");
-    }
-
     public CompilerOutputStyle getCompilerOutputStyle()
     {
         return compilerOutputStyle;
@@ -283,20 +278,16 @@ public abstract class AbstractCompiler
         }
     }
 
-    /**
-     * @deprecated use (String[]) arguments.toArray( new String[ arguments.size() ] ); instead
-     */
-    protected static String[] toStringArray( List<String> arguments )
+    protected void logCompiling( String[] sourceFiles, CompilerConfiguration config )
     {
-        String[] args = new String[arguments.size()];
-
-        int argLength = arguments.size();
-
-        for ( int i = 0; i < argLength; i++ )
+        if ( ( getLogger() != null ) && getLogger().isInfoEnabled() )
         {
-            args[i] = arguments.get( i );
+            String to = ( config.getWorkingDirectory() == null ) ? config.getOutputLocation() :
+                config.getWorkingDirectory().toPath().relativize( new File( config.getOutputLocation() ).toPath() ).toString();
+            getLogger().info( "Compiling " +
+                                  ( sourceFiles == null ? "" : ( sourceFiles.length + " source file" + ( sourceFiles.length == 1 ? " " : "s " ) ) ) +
+                                  "with " + getCompilerId() + " [" + config.describe() + "]" +
+                                  " to " + to );
         }
-
-        return args;
-    }
+  }
 }
