@@ -24,6 +24,8 @@ package org.codehaus.plexus.compiler;
  * SOFTWARE.
  */
 
+import org.codehaus.plexus.util.StringUtils;
+
 import java.io.File;
 import java.util.AbstractMap;
 import java.util.ArrayList;
@@ -470,31 +472,6 @@ public class CompilerConfiguration
         customCompilerArguments.add( new AbstractMap.SimpleImmutableEntry<>( customArgument, value ) );
     }
 
-    /**
-     * @deprecated will be removed in 2.X use #getCustomCompilerArgumentsAsMap
-     * @return
-     */
-    @Deprecated
-    public LinkedHashMap<String, String> getCustomCompilerArguments()
-    {
-        LinkedHashMap<String, String> arguments = new LinkedHashMap<>( customCompilerArguments.size() );
-        for ( Map.Entry<String, String> entry : customCompilerArguments )
-        {
-            arguments.put( entry.getKey(), entry.getValue() );
-        }
-        return arguments;
-    }
-
-    /**
-     * @deprecated will be removed in 2.X use #setCustomCompilerArgumentsAsMap
-     * @param customCompilerArguments
-     */
-    @Deprecated
-    public void setCustomCompilerArguments( LinkedHashMap<String, String> customCompilerArguments )
-    {
-        setCustomCompilerArgumentsAsMap( customCompilerArguments );
-    }
-
     /**
      * Get all unique argument keys and their value. In case of duplicate keys, last one added wins.
      *
@@ -812,4 +789,54 @@ public class CompilerConfiguration
     {
         this.implicitOption = implicitOption;
     }
+
+    public String describe()
+    {
+        List<String> params = new ArrayList<>();
+
+        if ( isFork() )
+        {
+            params.add( "forked" );
+        }
+
+        // base options: debug, optimize, verbose, deprecation
+        if ( isDebug() )
+        {
+            if ( StringUtils.isNotEmpty( getDebugLevel() ) )
+            {
+                params.add( "debug:" + getDebugLevel() );
+            }
+            else
+            {
+                params.add( "debug" );
+            }
+        }
+        if ( isOptimize() )
+        {
+            params.add( "optimize" );
+        }
+        if ( isVerbose() )
+        {
+            params.add( "verbose" );
+        }
+        if ( isShowDeprecation() )
+        {
+            params.add( "deprecation" );
+        }
+
+        // target bytecode options: release or target, module-path
+        if ( !StringUtils.isEmpty( getReleaseVersion() ) )
+        {
+            params.add( "release " + getReleaseVersion() );
+        }
+        else if ( !StringUtils.isEmpty( getTargetVersion() ) )
+        {
+            params.add( "target " + getTargetVersion() );
+        }
+        if ( getModulepathEntries() != null && !getModulepathEntries().isEmpty() )
+        {
+            params.add( "module-path" );
+        }
+        return String.join( " ", params );
+    }
 }
