@@ -303,6 +303,12 @@ public class AspectJCompiler
         super( CompilerOutputStyle.ONE_OUTPUT_FILE_PER_INPUT_FILE, "", ".class", null );
     }
 
+    @Override
+    public String getCompilerId()
+    {
+        return "aspectj";
+    }
+
     public CompilerResult performCompile( CompilerConfiguration config )
         throws CompilerException
     {
@@ -320,9 +326,7 @@ public class AspectJCompiler
             return new CompilerResult();
         }
 
-        System.out.println(
-            "Compiling " + sourceFiles.length + " " + "source file" + ( sourceFiles.length == 1 ? "" : "s" ) + " to "
-                + destinationDir.getAbsolutePath() );
+        logCompiling( sourceFiles, config );
 
         //        String[] args = buildCompilerArguments( config, sourceFiles );
         AjBuildConfig buildConfig = buildCompilerConfig( config );
