@@ -84,6 +84,12 @@ public class CSharpCompiler
     // Compiler Implementation
     // ----------------------------------------------------------------------
 
+    @Override
+    public String getCompilerId()
+    {
+        return "csharp";
+    }
+
     public boolean canUpdateTarget( CompilerConfiguration configuration )
         throws CompilerException
     {
@@ -115,8 +121,7 @@ public class CSharpCompiler
             return new CompilerResult().success( true );
         }
 
-        System.out.println( "Compiling " + sourceFiles.length + " " + "source file" +
-                                ( sourceFiles.length == 1 ? "" : "s" ) + " to " + destinationDir.getAbsolutePath() );
+        logCompiling( sourceFiles, config );
 
         String[] args = buildCompilerArguments( config, sourceFiles );
 
@@ -640,18 +645,6 @@ Options can be of the form -option or /option
         return result;
     }
 
-    /**
-     * This method is just here to maintain the public api. This is now handled in the parse
-     * compiler output function.
-     *
-     * @author Chris Stevenson
-     * @deprecated
-     */
-    public static CompilerMessage parseLine( String line )
-    {
-        return DefaultCSharpCompilerParser.parseLine( line );
-    }
-
     protected static Set<String> getSourceFilesForSourceRoot( CompilerConfiguration config, String sourceLocation )
     {
         DirectoryScanner scanner = new DirectoryScanner();
