@@ -72,6 +72,12 @@ public class EclipseJavaCompiler
     // ----------------------------------------------------------------------
     boolean errorsAsWarnings = false;
 
+    @Override
+    public String getCompilerId()
+    {
+        return "eclipse";
+    }
+
     @Override
     public CompilerResult performCompile( CompilerConfiguration config )
         throws CompilerException
@@ -251,6 +257,8 @@ public class EclipseJavaCompiler
 
         allSources = resortSourcesToPutModuleInfoFirst( allSources );
 
+        logCompiling( null, config );
+
         // Compile
         try
         {
