@@ -51,7 +51,7 @@ import java.util.Map;
  *         Ma&icirc;tre</a>
  *
  */
-@Component( role = Compiler.class, hint = "j2objc ")
+@Component( role = Compiler.class, hint = "j2objc")
 public class J2ObjCCompiler
     extends AbstractCompiler
 {
@@ -98,6 +98,12 @@ public class J2ObjCCompiler
     // Compiler Implementation
     // ----------------------------------------------------------------------
 
+    @Override
+    public String getCompilerId()
+    {
+        return "j2objc";
+    }
+
     public boolean canUpdateTarget( CompilerConfiguration configuration )
         throws CompilerException
     {
@@ -122,9 +128,7 @@ public class J2ObjCCompiler
             return new CompilerResult().success( true );
         }
 
-        System.out.println(
-            "Compiling " + sourceFiles.length + " " + "source file" + ( sourceFiles.length == 1 ? "" : "s" ) + " to "
-                + destinationDir.getAbsolutePath() );
+        logCompiling( sourceFiles, config );
 
         String[] args = buildCompilerArguments( config, sourceFiles );
 
