@@ -123,6 +123,12 @@ public class JavacCompiler
     // Compiler Implementation
     // ----------------------------------------------------------------------
 
+    @Override
+    public String getCompilerId()
+    {
+        return "javac";
+    }
+
     @Override
     public CompilerResult performCompile( CompilerConfiguration config )
         throws CompilerException
@@ -141,12 +147,7 @@ public class JavacCompiler
             return new CompilerResult();
         }
 
-        if ( ( getLogger() != null ) && getLogger().isInfoEnabled() )
-        {
-            getLogger().info( "Compiling " + sourceFiles.length + " " +
-                                  "source file" + ( sourceFiles.length == 1 ? "" : "s" ) +
-                                  " to " + destinationDir.getAbsolutePath() );
-        }
+        logCompiling( sourceFiles, config );
 
         String[] args = buildCompilerArguments( config, sourceFiles );
 
