@@ -27,6 +27,9 @@ package org.codehaus.plexus.compiler.javac;
 import org.codehaus.plexus.compiler.AbstractCompilerTest;
 import org.codehaus.plexus.compiler.CompilerConfiguration;
 import org.codehaus.plexus.util.StringUtils;
+import org.hamcrest.Matchers;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.io.File;
 import java.util.ArrayList;
@@ -36,6 +39,9 @@ import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.is;
+
 /**
  * @author <a href="mailto:jason@plexus.org">Jason van Zyl</a>
  */
@@ -44,25 +50,26 @@ public abstract class AbstractJavacCompilerTest
 {
     private static final String PS = File.pathSeparator;
 
+    @BeforeEach
     public void setUp()
-        throws Exception
     {
-        super.setUp();
         setCompilerDebug( true );
         setCompilerDeprecationWarnings( true );
-
     }
 
+    @Override
     protected String getRoleHint()
     {
         return "javac";
     }
 
+    @Override
     protected int expectedErrors()
     {
         String javaVersion = getJavaVersion();
-        if (javaVersion.contains("9.0")||javaVersion.contains("11")||javaVersion.contains("14")||javaVersion.contains("15")){
-            // lots of new warnings about obsoletions for future releases
+        if (javaVersion.contains("9.0")||javaVersion.contains("11")||javaVersion.contains("14")||
+            javaVersion.contains("15")||javaVersion.contains("16")||javaVersion.contains("17")||
+            javaVersion.contains("18")||javaVersion.contains("19")){
             return 5;
         }
         // javac output changed for misspelled modifiers starting in 1.6...they now generate 2 errors per occurrence, not one.
@@ -76,17 +83,15 @@ public abstract class AbstractJavacCompilerTest
         }
     }
 
+    @Override
     protected int expectedWarnings()
     {
         String javaVersion = getJavaVersion();
-        if (javaVersion.contains("9.0")||javaVersion.contains("11")||javaVersion.contains("14")||javaVersion.contains("15")){
+        if (javaVersion.contains("9.0")||javaVersion.contains("11")||javaVersion.contains("14")||
+            javaVersion.contains("15")||javaVersion.contains("16")||javaVersion.contains("17")||
+            javaVersion.contains("18")||javaVersion.contains("19")){
             return 1;
         }
-        if (javaVersion.contains("9.0")){
-            // lots of new warnings about obsoletions for future releases
-            return 8;
-        }
-
         if (javaVersion.contains("1.8")){
             // lots of new warnings about obsoletions for future releases
             return 30;
@@ -117,6 +122,18 @@ public abstract class AbstractJavacCompilerTest
         if (javaVersion.contains("15")){
             return "15";
         }
+        if (javaVersion.contains("16")){
+            return "16";
+        }
+        if (javaVersion.contains("17")){
+            return "17";
+        }
+        if (javaVersion.contains("18")){
+            return "18";
+        }
+        if (javaVersion.contains("19")){
+            return "19";
+        }
         return super.getTargetVersion();
     }
 
@@ -140,34 +157,54 @@ public abstract class AbstractJavacCompilerTest
         {
             return "15";
         }
+        if (javaVersion.contains("16")){
+            return "16";
+        }
+        if (javaVersion.contains("17")){
+            return "17";
+        }
+        if (javaVersion.contains("18")){
+            return "18";
+        }
+        if (javaVersion.contains("19")){
+            return "19";
+        }
         return super.getTargetVersion();
     }
 
+    @Override
     protected Collection<String> expectedOutputFiles()
     {
         String javaVersion = getJavaVersion();
-        if (javaVersion.contains("9.0")||javaVersion.contains("11")||javaVersion.contains("14")||javaVersion.contains("15"))
-        {
-            return Arrays.asList( new String[]{ "org/codehaus/foo/Deprecation.class", "org/codehaus/foo/ExternalDeps.class",
-                "org/codehaus/foo/Person.class"} );
+        if (javaVersion.contains("9.0")||javaVersion.contains("11")||javaVersion.contains("14")||
+            javaVersion.contains("15")||javaVersion.contains("16")||javaVersion.contains("17")||
+            javaVersion.contains("18")||javaVersion.contains("19")
+        ){
+            return Arrays.asList( "org/codehaus/foo/Deprecation.class", "org/codehaus/foo/ExternalDeps.class",
+                    "org/codehaus/foo/Person.class" );
         }
-        return Arrays.asList( new String[]{ "org/codehaus/foo/Deprecation.class", "org/codehaus/foo/ExternalDeps.class",
-            "org/codehaus/foo/Person.class", "org/codehaus/foo/ReservedWord.class" } );
+        return Arrays.asList( "org/codehaus/foo/Deprecation.class", "org/codehaus/foo/ExternalDeps.class",
+                "org/codehaus/foo/Person.class", "org/codehaus/foo/ReservedWord.class" );
     }
 
-    public void internalTest( CompilerConfiguration compilerConfiguration, List<String> expectedArguments )
-    {
-        String[] actualArguments = JavacCompiler.buildCompilerArguments( compilerConfiguration, new String[0] );
+    protected void internalTest(CompilerConfiguration compilerConfiguration, List<String> expectedArguments) {
+        internalTest(compilerConfiguration, expectedArguments, new String[0]);
+    }
 
-        assertEquals( "The expected and actual argument list sizes differ.", expectedArguments.size(),
-                      actualArguments.length );
+    public void internalTest(CompilerConfiguration compilerConfiguration, List<String> expectedArguments, String[] sources)
+    {
+        String[] actualArguments = JavacCompiler.buildCompilerArguments( compilerConfiguration, sources );
+
+        assertThat( "The expected and actual argument list sizes differ.",
+                actualArguments, Matchers.arrayWithSize(expectedArguments.size() ));
 
         for ( int i = 0; i < actualArguments.length; i++ )
         {
-            assertEquals( "Unexpected argument", expectedArguments.get( i ), actualArguments[i] );
+            assertThat( "Unexpected argument", actualArguments[i], is( expectedArguments.get( i ) ));
         }
     }
 
+    @Test
     public void testBuildCompilerArgs13()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -181,6 +218,7 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
     public void testBuildCompilerArgs14()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -194,6 +232,7 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
     public void testBuildCompilerArgs15()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -207,6 +246,7 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
     public void testBuildCompilerArgs18()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -220,6 +260,7 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
     public void testBuildCompilerArgsUnspecifiedVersion()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -231,6 +272,7 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
     public void testBuildCompilerDebugLevel()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -247,6 +289,7 @@ public abstract class AbstractJavacCompilerTest
     }
 
     // PLXCOMP-190
+    @Test
     public void testJRuntimeArguments()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -269,7 +312,7 @@ public abstract class AbstractJavacCompilerTest
         expectedArguments.add( "1.3" );
 
         // customCompilerArguments
-        Map<String, String> customCompilerArguments = new LinkedHashMap<String, String>();
+        Map<String, String> customCompilerArguments = new LinkedHashMap<>();
         customCompilerArguments.put( "-J-Duser.language=en_us", null );
         compilerConfiguration.setCustomCompilerArgumentsAsMap( customCompilerArguments );
         // don't expect this argument!!
@@ -277,6 +320,42 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
+    public void testModulePathAnnotations() throws Exception
+    {
+        List<String> expectedArguments = new ArrayList<>();
+
+        CompilerConfiguration compilerConfiguration = new CompilerConfiguration();
+
+        final String[] source = {"module-info.java"};
+
+        // outputLocation
+        compilerConfiguration.setOutputLocation( "/output" );
+        expectedArguments.add( "-d" );
+        expectedArguments.add( new File( "/output" ).getAbsolutePath() );
+
+        // failOnWarning
+        compilerConfiguration.setModulepathEntries( Arrays.asList( "/repo/a/b/1.0/b-1.0.jar",
+                "/repo/c/d/1.0/d-1.0.jar" ) );
+        expectedArguments.add( "--module-path" );
+        expectedArguments.add( "/repo/a/b/1.0/b-1.0.jar" + File.pathSeparator +
+                "/repo/c/d/1.0/d-1.0.jar" + File.pathSeparator );
+
+        compilerConfiguration.setProcessorModulePathEntries(Arrays.asList("/repo/a/b/1.0/annotations-1.0.jar",
+                "/repo/f/a/1.0/annotations-4.0.jar"));
+        expectedArguments.add( "--processor-module-path" );
+        expectedArguments.add("/repo/a/b/1.0/annotations-1.0.jar" + File.pathSeparator +
+                "/repo/f/a/1.0/annotations-4.0.jar" + File.pathSeparator );
+
+        // releaseVersion
+        compilerConfiguration.setReleaseVersion( "9" );
+        expectedArguments.add( "--release" );
+        expectedArguments.add( "9" );
+
+        internalTest( compilerConfiguration, expectedArguments, source);
+    }
+
+    @Test
     public void testModulePath() throws Exception
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -304,6 +383,7 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
     public void testModuleVersion()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -329,6 +409,7 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
     public void testReleaseVersion()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -348,6 +429,7 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
     public void testFailOnWarning()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -372,6 +454,7 @@ public abstract class AbstractJavacCompilerTest
         internalTest( compilerConfiguration, expectedArguments );
     }
 
+    @Test
     public void testMultipleAddExports()
     {
         List<String> expectedArguments = new ArrayList<>();
@@ -442,7 +525,7 @@ public abstract class AbstractJavacCompilerTest
 
         // classpathEntires
 
-        List<String> classpathEntries = new ArrayList<String>();
+        List<String> classpathEntries = new ArrayList<>();
 
         classpathEntries.add( "/myjar1.jar" );
 
@@ -456,7 +539,7 @@ public abstract class AbstractJavacCompilerTest
 
         // sourceRoots
 
-        List<String> compileSourceRoots = new ArrayList<String>();
+        List<String> compileSourceRoots = new ArrayList<>();
 
         compileSourceRoots.add( "/src/main/one" );
 
@@ -528,7 +611,7 @@ public abstract class AbstractJavacCompilerTest
 
         // customerCompilerArguments
 
-        Map<String, String> customerCompilerArguments = new LinkedHashMap<String, String>();
+        Map<String, String> customerCompilerArguments = new LinkedHashMap<>();
 
         customerCompilerArguments.put( "arg1", null );
 
